[dpkg] 55/200: Dpkg::Build::Info: Whitelist other DPKG_ namespaced variables
Ximin Luo
infinity0 at debian.org
Wed Apr 5 15:17:15 UTC 2017
This is an automated email from the git hooks/post-receive script.
infinity0 pushed a commit to branch master
in repository dpkg.
commit 08ac6a92b4f4366548472464ebfb86708b124a5c
Author: Guillem Jover <guillem at debian.org>
Date: Tue Nov 29 02:26:11 2016 +0100
Dpkg::Build::Info: Whitelist other DPKG_ namespaced variables
---
debian/changelog | 3 +++
scripts/Dpkg/Build/Info.pm | 12 ++++++++++--
scripts/t/Dpkg_Build_Info.t | 2 +-
3 files changed, 14 insertions(+), 3 deletions(-)
diff --git a/debian/changelog b/debian/changelog
index 429bcb7..fec3969 100644
--- a/debian/changelog
+++ b/debian/changelog
@@ -1,6 +1,9 @@
dpkg (1.18.16) UNRELEASED; urgency=medium
[ Guillem Jover ]
+ * Perl modules:
+ - Whitelist DPKG_GENSYMBOLS_CHECK_LEVEL, DPKG_ROOT, DPKG_ADMINDIR and
+ DPKG_DATADIR environment variables in Dpkg::Build::Info.
* Documentation:
- State the current working directory used when running dpkg-buildpackage
hooks.
diff --git a/scripts/t/Dpkg_Build_Info.t b/scripts/t/Dpkg_Build_Info.t
index 5799885..3f67c3a 100644
--- a/scripts/t/Dpkg_Build_Info.t
+++ b/scripts/t/Dpkg_Build_Info.t
@@ -22,7 +22,7 @@ BEGIN {
use_ok('Dpkg::Build::Info');
}
-is(scalar Dpkg::Build::Info::get_build_env_whitelist(), 46,
+is(scalar Dpkg::Build::Info::get_build_env_whitelist(), 50,
'whitelisted environment variables array');
1;
diff --git a/scripts/Dpkg/Build/Info.pm b/scripts/Dpkg/Build/Info.pm
index b9043fa..4935f0f 100644
--- a/scripts/Dpkg/Build/Info.pm
+++ b/scripts/Dpkg/Build/Info.pm
@@ -63,8 +63,16 @@ my @env_whitelist = (
qw(DEB_BUILD_OPTIONS DEB_BUILD_PROFILES),
# DEB_flag_{SET,STRIP,APPEND,PREPEND} will be recorded after being merged
# with system config and user config.
- qw(DEB_VENDOR), # See deb-vendor(1).
- qw(DPKG_ORIGINS_DIR), # See Dpkg::Vendor(3).
+ # See deb-vendor(1).
+ qw(DEB_VENDOR),
+ # See dpkg(1).
+ qw(DPKG_ROOT DPKG_ADMINDIR),
+ # See dpkg-architecture(1).
+ qw(DPKG_DATADIR),
+ # See Dpkg::Vendor(3).
+ qw(DPKG_ORIGINS_DIR),
+ # See dpkg-gensymbols(1).
+ qw(DPKG_GENSYMBOLS_CHECK_LEVEL),
# See <https://reproducible-builds.org/specs/source-date-epoch>.
qw(SOURCE_DATE_EPOCH),
);
--
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/reproducible/dpkg.git
More information about the Reproducible-commits
mailing list